@@ -13,3 +13,7 @@
 #loadModule("yada", TRUE)
 #loadModule("stdVector", TRUE)
 loadModule("mod_Rmumps", TRUE)
+.onLoad <- function(libname, pkgname){
+  for (cc in cnsts)
+     assign(cc, get_cnst(cc), envir = parent.env(environment()))
+}
